# Example 10.4, Effects of Personal Exemption on Fertility Rates
# Data set: fertil3

# Function for result reporting
source("_report.R")

# Load the data and estimate the models in the background
load("fertil3.Rdata")
names(data)[names(data)=="gfr"]="gfr.t"
names(data)[names(data)=="pe"]="pe.t"
names(data)[names(data)=="pe_1"]="pe.t_1"
names(data)[names(data)=="pe_2"]="pe.t_2"
names(data)[names(data)=="ww2"]="ww2.t"
names(data)[names(data)=="pill"]="pill.t"
tsdata=ts(data,start=1913,frequency=1)
model1=lm(gfr.t~pe.t+ww2.t+pill.t,data=tsdata)
model2=lm(gfr.t~pe.t+pe.t_1+pe.t_2+ww2.t+pill.t,data=tsdata)
dig1=c(2,3,2,2,3)
dig2=c(2,3,4,3,2,2,3)

# Describe first model
cat("Model to estimate: gfr.t = beta0 + beta1 * pe.t + beta2 * ww2.t + beta3 * pill.t + u.t",
    "\nwhere gfr is ", paste(desc[desc[,1]=="gfr",2]),
    "\npe is ", paste(desc[desc[,1]=="pe",2]),
    "\nww2 is ", paste(desc[desc[,1]=="ww2",2]),
    "\nand pill is ", paste(desc[desc[,1]=="pill",2]),
    sep="")

# Report results
{
  cat("The estimated regression line is")
  reportreg(model1,dig1,suffix=".hat",adj=T)
}

# Interpretation
cat("Each variable is statistically significant at the 1% level against a two-sided alternative. gfr was lower during World War II, and has been lower after the introduction of the birth control pill",
    "\nThe average pe over the period was ", round(mean(data[,"pe.t"]),2), ", ranging from zero to ", max(data[,"pe.t"]),
    ". The coefficient on pe indicates that an increase of about $", round(1/as.numeric(printcoef(model1,2,dig1[2]))),
    " in pe on average raised gfr by 1 per 1000 women",
    sep="")

# Estimate the FDL model
{
  cat("Expecting gfr to react to changes in pe with a lag, we further estimate a distributed lag model with two lags. The estimated regression line is")
  reportreg(model2,dig2,suffix=".hat",adj=T)
}

# Interpretation
data$diff1=data$pe.t_1-data$pe.t
data$diff2=data$pe.t_2-data$pe.t
tsdata=ts(data,start=1913,frequency=1)
m0=lm(gfr.t~pe.t+diff1+diff2+ww2.t+pill.t,data=tsdata)
tsdata=ts(data[-c(1:2),],start=1915,frequency=1)    # Remove first two observations to get comparable restricted model
m1=lm(gfr.t~ww2.t+pill.t,data=tsdata)
m2=lm(gfr.t~pe.t+ww2.t+pill.t,data=tsdata)
Fstat1=round((summary(model2)$r.squared-summary(m1)$r.squared)/(1-summary(model2)$r.squared)*(nrow(model2$model)-nrow(summary(model2)$coef))/3,2)
p1=round(pf(Fstat1,3,nrow(model2$model)-nrow(summary(model2)$coef),lower.tail=F),3)
Fstat2=round((summary(model2)$r.squared-summary(m2)$r.squared)/(1-summary(model2)$r.squared)*(nrow(model2$model)-nrow(summary(model2)$coef))/2,2)
p2=round(pf(Fstat2,2,nrow(model2$model)-nrow(summary(model2)$coef),lower.tail=F),3)
cat("The number of observations in this model becomes ", nrow(model2$model), " because two is lost when pe is lagged twice. The coefficients on the pe variables are estimated very imprecisely, and each is individually insignificant. This occurs because of the strong correlation between the three variables, and multicollinearity makes it difficult to estimate the effect at each lag. However, the pe variables are jointly significant, with a F statistic of ",
    Fstat1, " and a p-value of ", p1, ". Therefore, as the static model suggested, pe does have an effect on gfr, but we cannot determine whether the effect is contemporaneous or with a one-/two-year lag. Actually, pe.t_1 and pe.t_2 are jointly insignificant in this model (F = ",
    Fstat2, ", p-value = ", p2, "), so at this point, we would be justified in using the static model",
    "\nNow we look at the long-run propensity. LRP is estimated to be ",
    printcoef(model2,2,dig2[2]), " - ", printabscoef(model2,3,dig2[3]), " + ", printcoef(model2,4,dig2[4]), " = ",
    round(as.numeric(printcoef(model2,2,dig2[2]))+as.numeric(printcoef(model2,3,dig2[3]))+as.numeric(printcoef(model2,4,dig2[4])),3),
    ". To obtain the standard error of LRP, we let theta0 = delta0 + delta1 + delta2, and substitute delta0 = theta0 - delta1 - delta2 into the model:",
    "\ngfr.t = alpha0 + delta0 * pe.t + delta1 * pe.t_1 + delta2 * pe.t_2 + ...",
    "\nso it becomes",
    "\ngfr.t = alpha0 + theta0 * pe.t + delta1 * (pe.t_1 - pe.t) + delta2 * (pe.t_2 - pe.t) + ...",
    "\nRegressing gfr.t on pe.t, (pe.t_1 - pe.t), (pe.t_2 - pe.t), ww2.t and pill.t gives theta0hat = ",
    printcoef(m0,2,3), " and its standard error equal to ", printse(m0,2,3), ". The t statistic for theta0hat is ",
    printt(m0,2,3), ", so thata0hat is statistically significant. Therefore, while none of the pe variables is individually significant, the LRP is very significant",
    sep="")