# Example 12.4, Prais-Winsten Estimation in the Event Study
# Data set: barium

# Function for result reporting
source("_report.R")

# Load the data and estimate the original model
load("barium.Rdata")
tsdata=ts(data,start=c(1978,2),frequency=12)
model1=lm(lchnimp~lchempi+lgas+lrtwex+befile6+affile6+afdec6,data=tsdata)
dig1=c(2,2,3,3,3,3,3)

# PW estimation
rho=0
m=model1
tilda=tsdata[,c("lchnimp","lchempi","lgas","lrtwex","befile6","affile6","afdec6")]
obs1=tilda[1,]
uhat.t=ts(m$residuals)
repeat{
  oldrho=rho
  res=as.data.frame(cbind(uhat.t,uhat.t_1=lag(uhat.t,k=-1)))
  mres=lm(uhat.t~0+uhat.t_1,data=res)
  rho=as.numeric(mres$coef[1])
  if(abs(oldrho-rho)<10^(-8)) break
  tilda=cbind(lchnimp=tsdata[,"lchnimp"]-rho*lag(tsdata[,"lchnimp"],k=-1),
              lchempi=tsdata[,"lchempi"]-rho*lag(tsdata[,"lchempi"],k=-1),
              lgas=tsdata[,"lgas"]-rho*lag(tsdata[,"lgas"],k=-1),
              lrtwex=tsdata[,"lrtwex"]-rho*lag(tsdata[,"lrtwex"],k=-1),
              befile6=tsdata[,"befile6"]-rho*lag(tsdata[,"befile6"],k=-1),
              affile6=tsdata[,"affile6"]-rho*lag(tsdata[,"affile6"],k=-1),
              afdec6=tsdata[,"afdec6"]-rho*lag(tsdata[,"afdec6"],k=-1)
              )
  tilda=ts(rbind(obs1*(1-rho^2)^0.5,tilda))
  cons=c((1-rho^2)^0.5,rep(1-rho,nrow(tsdata)-1))
  m=lm(lchnimp~0+cons+lchempi+lgas+lrtwex+befile6+affile6+afdec6,data=tilda)
  fit=m$coef[1]+m$coef[2]*tsdata[,"lchempi"]+m$coef[3]*tsdata[,"lgas"]+m$coef[4]*tsdata[,"lrtwex"]+m$coef[5]*tsdata[,"befile6"]+m$coef[6]*tsdata[,"affile6"]+m$coef[7]*tsdata[,"afdec6"]
  uhat.t=ts(tsdata[,"lchnimp"]-fit)
}
model2=m
dig2=c(2,2,2,2,3,3,3)

# Prepare for result reporting

# Create row names
temp0=c(names(model1$coef)[-1],"intercept")
temp1=vector()
for (n in c(1:7)) {
  temp1[2*n-1]=temp0[n]
  temp1[2*n]=""
}
temp1[15:17]=c("rhohat","Observations","R-squared")
# Append columns of results to the table
for (n in c(1:2)) {
  temp2=vector()
  # Fill in coefficients and SEs of independent variables
  modelname=eval(parse(text=paste("model",n,sep="")))
  digname=eval(parse(text=paste("dig",n,sep="")))
  nvar=nrow(summary(modelname)$coef)-1
  for (m in c(1:nvar)) {
    nspace.coef=3-ninteger(as.numeric(printcoef(modelname,m+1,digname[m+1])),T)  # For formatting; so are similar statements below
    temp2[2*m-1]=paste(paste(rep(" ",nspace.coef),collapse=""),printcoef(modelname,m+1,digname[m+1])," ",sep="")
    nspace.se=3-1-ninteger(as.numeric(printse(modelname,m+1,digname[m+1])))
    temp2[2*m]=paste(paste(rep(" ",nspace.se),collapse=""),"(",printse(modelname,m+1,digname[m+1]),")",sep="")
  }
  # Fill the intercept coefficients/SEs, no. of obs. and R^2
  nspace.coef=3-ninteger(as.numeric(printcoef(modelname,1,digname[1])),T)
  nspace.se=3-1-ninteger(as.numeric(printse(modelname,1,digname[1])))
  temp2[13]=paste(paste(rep(" ",nspace.coef),collapse=""),printcoef(modelname,1,digname[1])," ",sep="")
  temp2[14]=paste(paste(rep(" ",nspace.se),collapse=""),"(",printse(modelname,1,digname[1]),")",sep="")
  if(n==1) temp2[15]="   -" else temp2[15]=paste(" ",round(rho,3),sep="")
  temp2[16]=paste("   ",nrow(modelname$model),sep="")
  if(n==1) temp2[17]=paste(" ",printr(model1,3),sep="")
  else temp2[17]=paste(" ",printr(lm(lchnimp~cons+lchempi+lgas+lrtwex+befile6+affile6+afdec6,data=tilda),3),sep="")
  temp1=data.frame(temp1,temp2)
}
table=temp1
names(table)=c("Coefficient","OLS","Prais-Winsten")

# Describe the models and present the results
{
  cat("This example closely follows Example 10.5. In the previous example, we estimated the model: lchnimp = beta0 + beta1 * lchempi + beta2 * lgas + beta3 * lrtwex + beta4 * befile6 + beta5 * affile6 + beta6 * afdec6 + u. Here, to correct for the serial correlation in the data set, we estimate the regression again, using iterated Prais-Winsten estimation (in the AR(1) model of residuals, no intercept is estimated). Both the OLS and PW results are presented in the following table:\n\n")
  print(table,row.names=F,right=F)
}

# Interpretation
cat("The statistically significant coefficients, in particular those on lchempi, lrtwex and lafdec6, do not differ much across both estimations. In contrast, the statistically insignificant coefficients can change a lot across different estimation methods",
    "\nThe standard errors in the right column are uniformly larger than those on the left. This is because OLS standard errors usually understate the actual sampling variation in the OLS estimates when serial correlation is present. With the PW estimation, the t statistic on afdec6 becomes ",
    printt(model2,7,dig2[7]), ", as opposed to ", printt(model1,7,dig1[7]), " with the OLS estimates, indicating a less statistically significant effect on chnimp after the ITC's decision compared to our conclusion in Example 10.5",
    "\nIn addition, it is necessary to note that while the two R-squareds differ by a lot in this example, they are not comparable. The R^2 for OLS is the usual R^2, but that for PW is from the final regression of the transformed dependent variable on the transformed independent variables, i.e. the one which, when t ≥ 2, is given by",
    "\ny.t - rho * y.t_1 = beta0 + beta0' * (1 - rho) + beta1 * (x1.t - rho * x1.t_1) + ... + betak * (xk.t - rho * xk.t_1) + e.t",
    "\nThis R^2 does not have a clear interpretation, but is reported by convention",
    sep="")