# Example 12.5, Static Phillips Curve
# Data set: phillips

# Function for result reporting
source("_report.R")

# Load the data and estimate the original model
load("phillips.Rdata")
data=data[data$year<=1996,]    # Refine the data
tsdata=ts(data,start=1948,frequency=1)
model1=lm(inf~unem,data=tsdata)
dig1=c(3,3)

# PW estimation
rho=0
m=model1
tilda=tsdata[,c("inf","unem")]
obs1=tilda[1,]
uhat.t=ts(m$residuals)
repeat{
  oldrho=rho
  res=as.data.frame(cbind(uhat.t,uhat.t_1=lag(uhat.t,k=-1)))
  mres=lm(uhat.t~0+uhat.t_1,data=res)
  rho=as.numeric(mres$coef[1])
  if(abs(oldrho-rho)<10^(-8)) break
  tilda=cbind(lchnimp=tsdata[,"inf"]-rho*lag(tsdata[,"inf"],k=-1),
              lchempi=tsdata[,"unem"]-rho*lag(tsdata[,"unem"],k=-1)
              )
  tilda=ts(rbind(obs1*(1-rho^2)^0.5,tilda))
  cons=c((1-rho^2)^0.5,rep(1-rho,nrow(tsdata)-1))
  m=lm(inf~0+cons+unem,data=tilda)
  fit=m$coef[1]+m$coef[2]*tsdata[,"unem"]
  uhat.t=ts(tsdata[,"inf"]-fit)
}
model2=m
dig2=c(3,3)

# Prepare for result reporting

# Create row names
temp0=c(names(model1$coef)[-1],"intercept")
temp1=vector()
for (n in c(1:2)) {
  temp1[2*n-1]=temp0[n]
  temp1[2*n]=""
}
temp1[5:7]=c("rhohat","Observations","R-squared")
# Append columns of results to the table
for (n in c(1:2)) {
  temp2=vector()
  # Fill in coefficients and SEs of independent variables
  modelname=eval(parse(text=paste("model",n,sep="")))
  digname=eval(parse(text=paste("dig",n,sep="")))
  nspace.coef=3-ninteger(as.numeric(printcoef(modelname,2,digname[2])),T)  # For formatting; so are similar statements below
  temp2[1]=paste(paste(rep(" ",nspace.coef),collapse=""),printcoef(modelname,2,digname[2])," ",sep="")
  nspace.se=3-1-ninteger(as.numeric(printse(modelname,2,digname[2])))
  temp2[2]=paste(paste(rep(" ",nspace.se),collapse=""),"(",printse(modelname,2,digname[2]),")",sep="")
  # Fill the intercept coefficients/SEs, no. of obs. and R^2
  nspace.coef=3-ninteger(as.numeric(printcoef(modelname,1,digname[1])),T)
  nspace.se=3-1-ninteger(as.numeric(printse(modelname,1,digname[1])))
  temp2[3]=paste(paste(rep(" ",nspace.coef),collapse=""),printcoef(modelname,1,digname[1])," ",sep="")
  temp2[4]=paste(paste(rep(" ",nspace.se),collapse=""),"(",printse(modelname,1,digname[1]),")",sep="")
  if(n==1) temp2[5]="    -" else temp2[5]=paste("  ",round(rho,3),sep="")
  temp2[6]=paste("    ",nrow(modelname$model),sep="")
  if(n==1) temp2[7]=paste("  ",printr(model1,3),sep="")
  else temp2[7]=paste("  ",printr(lm(inf~cons+unem,data=tilda),3),sep="")
  temp1=data.frame(temp1,temp2)
}
table=temp1
names(table)=c("Coefficient","OLS","Prais-Winsten")

# Describe the models and present the results
{
  cat("This example closely follows Example 10.1. In the previous example, we estimated the model: inf = beta0 + beta1 * unem + u, i.e. the static Phillips curve. Here, to correct for the serial correlation in the data set, we estimate the regression again, using iterated Prais-Winsten estimation (in the AR(1) model of residuals, no intercept is estimated). Both the OLS and PW results are presented in the following table:\n\n")
  print(table,row.names=F,right=F)
}

# Interpretation
cat("The coefficient on unem differ markedly between both estimation methods. The PW estimate suggests a tradeoff between inf and unem, and seems more plausible",
    "\nIn fact, a regression using the first-differenced inf and unem gives a slope coefficient of ",
    printcoef(lm(cinf~cunem,data=data),2,3), ", somewhat similar to the PW estimate. It could be that inf and unem are not related in levels, but have a negative relationship in first differences",
    sep="")