# Example 8.6, Financial Wealth Equation
# Data set: 401ksubs

# Function for result reporting
source("_report.R")

# Load the data, create new variable and estimate the models
load("401ksubs.Rdata")
data=data[data$fsize==1,]    # Refine the data
data$age25sq=(data$age-25)^2
model1=lm(nettfa~inc,data=data)
model2=lm(nettfa~inc,weights=1/inc,data=data)
model3=lm(nettfa~inc+age25sq+male+e401k,data=data)
model4=lm(nettfa~inc+age25sq+male+e401k,weights=1/inc,data=data)
dig1=c(2,3)
dig2=c(2,3)
dig3=c(2,3,4,2,2)
dig4=c(2,3,4,2,2)

# Prepare for result reporting. The relevant codes are borrowed from Example 4.10, with improvements in terms of simplicity and formatting

# Create row names
temp0=c(names(model4$coef)[-1],"intercept")
temp1=vector()
for (n in c(1:5)) {
  temp1[2*n-1]=temp0[n]
  temp1[2*n]=""
}
temp1[3]="(age - 25)^2"
temp1[11:12]=c("Observations","R-squared")
# Append columns of results to the table
for (n in c(1:4)) {
  temp2=vector()
  # Fill in coefficients and SEs of independent variables
  modelname=eval(parse(text=paste("model",n,sep="")))
  digname=eval(parse(text=paste("dig",n,sep="")))
  nvar=nrow(summary(modelname)$coef)-1
  for (m in c(1:nvar)) {
    nspace.coef=3-ninteger(as.numeric(printcoef(modelname,m+1,digname[m+1])),T)  # For formatting; so are similar statements below
    temp2[2*m-1]=paste(paste(rep(" ",nspace.coef),collapse=""),printcoef(modelname,m+1,digname[m+1])," ",sep="")
    nspace.se=3-1-ninteger(as.numeric(printse(modelname,m+1,digname[m+1])))
    temp2[2*m]=paste(paste(rep(" ",nspace.se),collapse=""),"(",printse(modelname,m+1,digname[m+1],n==1|n==3),")",sep="")
      # "n==1|n==3" for reporting HC-robust SEs for OLS
  }
  nemp=8-2*nvar
  # Fill the empty cells
  if (nemp>0) for (p in c(1:nemp)) temp2[2*nvar+p]="   -"
  # Fill the intercept coefficients/SEs, no. of obs. and R^2
  nspace.coef=3-ninteger(as.numeric(printcoef(modelname,1,digname[1])),T)
  nspace.se=3-1-ninteger(as.numeric(printse(modelname,1,digname[1])))
  temp2[9]=paste(paste(rep(" ",nspace.coef),collapse=""),printcoef(modelname,1,digname[1])," ",sep="")
  temp2[10]=paste(paste(rep(" ",nspace.se),collapse=""),"(",printse(modelname,1,digname[1],n==1|n==3),")",sep="")
  temp2[11]=paste("    ",nrow(modelname$model),sep="")
  temp2[12]=paste(" ",printr(modelname,4))
  temp1=data.frame(temp1,temp2)
}
table=temp1
names(table)=c("Independent Variables","(1) OLS","(2) WLS","(3) OLS","(4) WLS")

# Describe the model
cat("We estimate two models,\n\tnettfa = beta0 + beta1 * inc + u\nand\n\tnettfa = beta0 + beta1 * inc + beta2 * (age - 25)^2 + beta3 * male + beta4 * e401k + u\nrepectively",
    ", where nettfa is ", paste(desc[desc[,1]=="nettfa",2]),
    "\ninc is ", paste(desc[desc[,1]=="inc",2]),
    "\nage is ", paste(desc[desc[,1]=="age",2]),
    "\nmale is ", paste(desc[desc[,1]=="male",2]),
    "\nand e401k is ", paste(desc[desc[,1]=="e401k",2]),
    "\nFor both models, we do OLS and WLS estimations, the latter under the assumption Var(u|inc) = sigma^2 * inc. Because we suspect heteroskedasticity, we report the heteroskedasticity-robust standard errors for OLS",
    sep="")

# Report results
{
  cat("The estimation results are summarized in the table below:\n\n",
      "\tDependent Variable: nettfa\n")
  print(table,row.names=F,right=F)
}

# Interpretation
cat("No other factors controlled for, an $1 increase in inc is predicted to raise nettfa by $",
    printcoef(model1,2,dig1[2]), " using OLS estimates, or $",
    printcoef(model2,2,dig2[2]), " using WLS. The difference is not large; however, the WLS coefficient has a smaller standard error, and is thus more accurate, provided our assumption about the form of heteroskedasticity is correct",
    "\nAfter the other factors are controlled for, the effect of inc on nettfa becomes smaller in both cases, with the WLS estimate still more precise",
    "\nAge has an increasing effect at age over 25, and the effect is larger in the OLS estimate. The WLS estimate on age is also more precise",
    "\nThe effect of male is not statistically significant",
    "\nAs for e401k, the OLS estimate predicts an eligible person to have nettfa $",
    1000*as.numeric(printcoef(model3,5,dig3[5])), " higher than his ineligible counterpart; the WLS estimate is substantially below the OLS estimate and suggests a misspecification of the functional form in the mean equation",
    "\nUsing WLS, the F statistic for joint significance of (age - 25)^2, male and e401k is ",
    round((as.numeric(printr(model4,4))-as.numeric(printr(model2,4)))/(1-as.numeric(printr(model4,4)))*((nrow(model4$model)-nrow(summary(model4)$coef))/3),1),
    ". Thus, the variables jointly are very significant",
    sep="")